@@ -22,6 +22,10 @@ from tempest import test
 
 class AcceleratorRequestNegativeTest(base.BaseAPITest):
 
+    @classmethod
+    def skip_checks(cls):
+        super(AcceleratorRequestNegativeTest, cls).skip_checks()
+
     credentials = ['admin']
 
     @test.attr(type=['negative', 'gate'])
@@ -31,3 +35,12 @@ class AcceleratorRequestNegativeTest(base.BaseAPITest):
         self.assertRaises(lib_exc.NotFound,
                           self.os_admin.cyborg_client.get_accelerator_request,
                           non_existent_id)
+
+    @test.attr(type=['negative', 'gate'])
+    def test_delete_non_existent_accelerator_request(self):
+        # delete the non-existent accelerator request
+        non_existent_id = str(uuid.uuid4())
+        self.assertRaises(
+            lib_exc.NotFound,
+            self.os_admin.cyborg_client.delete_accelerator_request,
+            non_existent_id)
